@@ -577,4 +577,4 @@ def calculate_distance_matrix(file, n_trees, output_file):
 
     distance_matrix = pd.DataFrame(distance_matrix + distance_matrix_lower)
     distance_matrix.to_csv(output_file)
-    return distance_matrix
+    return distance_matrix.values
